@@ -3,7 +3,7 @@ import string
 import mmap
 import numpy as np
 
-from records import NpyFastaRecord, FastaRecord
+from records import NpyFastaRecord
 
 _complement = string.maketrans('ATCGatcgNnXx', 'TAGCtagcNnXx')
 complement  = lambda s: s.translate(_complement)
@@ -11,7 +11,7 @@ complement  = lambda s: s.translate(_complement)
 class Fasta(dict):
     def __init__(self, fasta_name, record_class=NpyFastaRecord):
         """
-            >>> from pyfasta import Fasta
+            >>> from pyfasta import Fasta, FastaRecord
 
             >>> f = Fasta('tests/data/three_chrs.fasta', 
             ...                          record_class=FastaRecord)
@@ -77,12 +77,13 @@ class Fasta(dict):
         return len(self.index)
 
     def iterkeys(self):
-        for k in self.keys(): yield k
+        for k in self.index.iterkeys(): yield k
+
     def keys(self):
         return self.index.keys()
     
     def __contains__(self, key):
-        return key in self.index.keys()
+        return key in self.index
 
     def __getitem__(self, i):
         # this implements the lazy loading
